#include "orbsvcs/CosEvent/CEC_Factory.h"
#include "ace/Dynamic_Service.h"

TAO_BEGIN_VERSIONED_NAMESPACE_DECL

TAO_CEC_Factory::~TAO_CEC_Factory ()
{
}

TAO_END_VERSIONED_NAMESPACE_DECL
